@@ -1,8 +1,6 @@
 __author__ = 'Akuukis <akuukis@kalvis.lv>'
 import datetime
-import math
 
-from beancount.core.amount import Amount
 from beancount.core.data import filter_txns
 from beancount.core.number import D
 
@@ -10,13 +8,14 @@ from .common import extract_mark_tx
 from .common import new_whole_entries
 from .common import read_config
 from .common import parse_mark
+from .common import get_number_of_txn
 
 __plugins__ = ['recur']
 
 
-def dublicate_over_period(params, default_date, value, config):
+def duplicate_over_period(params, default_date, value, config):
     begin_date, duration, step = parse_mark(params, default_date, config)
-    period = math.floor( duration / step )
+    period = get_number_of_txn(begin_date, duration, step)
 
     if(period > config['max_new_tx']):
         period = config['max_new_tx']
@@ -24,18 +23,22 @@ def dublicate_over_period(params, default_date, value, config):
 
     dates = []
     amounts = []
-    date = begin_date
-    while date < begin_date + datetime.timedelta(days=duration) and date <= datetime.date.today():
-        amounts.append( D(str(value)) )
-        dates.append(date)
-        date = date + datetime.timedelta(days=step)
+    i = 0
+    end_date = begin_date + duration
+    today_date = datetime.date.today()
+    tmp_date = begin_date + i * step
+    while tmp_date < end_date and tmp_date <= today_date:
+        amounts.append(D(str(value)))
+        dates.append(tmp_date)
+        i += 1
+        tmp_date = begin_date + i * step
 
     return (dates, amounts)
 
 
 def recur(entries, options_map, config_string=""):
     """
-    Beancount plugin: Dublicates all entry postings over time.
+    Beancount plugin: Duplicates all entry postings over time.
 
     Args:
       entries: A list of directives. We're interested only in the Transaction instances.
@@ -85,7 +88,7 @@ def recur(entries, options_map, config_string=""):
                     tags=tx.tags.difference([alias]),
                 )
 
-        newEntries = newEntries + new_whole_entries(tx, params, dublicate_over_period, config)
+        newEntries = newEntries + new_whole_entries(tx, params, duplicate_over_period, config)
 
     for trash in trashbin:
         entries.remove(trash)
